#
# spec file for package perl-Exception-Class
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Exception-Class
Name:           perl-Exception-Class
Version:        1.45
Release:        1.16
Summary:        Module that allows you to declare real exception classes in Perl
License:        Artistic-1.0 OR GPL-1.0-or-later
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/D/DR/DROLSKY/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Class::Data::Inheritable) >= 0.02
BuildRequires:  perl(Devel::StackTrace) >= 2.00
BuildRequires:  perl(Test::More) >= 0.96
Requires:       perl(Class::Data::Inheritable) >= 0.02
Requires:       perl(Devel::StackTrace) >= 2.00
%{perl_requires}

%description
*RECOMMENDATION 1*: If you are writing modern Perl code with Moose or Moo I
highly recommend using Throwable instead of this module.

*RECOMMENDATION 2*: Whether or not you use Throwable, you should use
Try::Tiny.

Exception::Class allows you to declare exception hierarchies in your
modules in a "Java-esque" manner.

It features a simple interface allowing programmers to 'declare' exception
classes at compile time. It also has a base exception class,
Exception::Class::Base, that can be easily extended.

It is designed to make structured exception handling simpler and better by
encouraging people to use hierarchies of exceptions in their applications,
as opposed to a single catch-all exception class.

This module does not implement any try/catch syntax. Please see the "OTHER
EXCEPTION MODULES (try/catch syntax)" section for more information on how
to get this syntax.

You will also want to look at the documentation for Exception::Class::Base,
which is the default base class for all exception objects created by this
module.

%prep
%autosetup  -n %{cpan_name}-%{version}
find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc azure-pipelines.yml Changes CODE_OF_CONDUCT.md CONTRIBUTING.md precious.toml README.md
%license LICENSE

%changelog
* Mon May  3 2021 Tina Müller <timueller+perl@suse.de>
- updated to 1.45
  see /usr/share/doc/packages/perl-Exception-Class/Changes
  1.45    2021-05-02
  - The field names for an exception are now checked to ensure that they are
    valid Perl identifiers. Implemented by brian d foy. PR #13.
* Mon Dec 11 2017 coolo@suse.com
- updated to 1.44
  see /usr/share/doc/packages/perl-Exception-Class/Changes
  1.44    2017-12-10
  - You can now pass "frame_filter", "filter_frames_early", and "skip_frames" to
    the throw() method of an exception class. These will be passed on to the
    Devel::StackTrace constructor. Requested by Frédéric Brière. GH #6.
* Mon Jul 10 2017 coolo@suse.com
- updated to 1.43
  see /usr/share/doc/packages/perl-Exception-Class/Changes
  1.43    2017-07-09
  - The full_message() method in Exception::Class::Base now calls message()
    instead of accessing the object's hash key. This makes it easier to override
    message() in a subclass. Patch by Alexander Batyrshin. PR #11.
* Fri Jan  6 2017 coolo@suse.com
- updated to 1.42
  see /usr/share/doc/packages/perl-Exception-Class/Changes
  1.42    2017-01-04
  - Generated exception classes are now added to %%INC. If you subclass a
    generated class with "use base" then base.pm will no longer attempt to load
    the requested class. Patch by Todd Rinaldo. PR #8.
* Thu Dec  8 2016 coolo@suse.com
- updated to 1.41
  see /usr/share/doc/packages/perl-Exception-Class/Changes
  1.41    2016-12-07
  - Switch to GitHub Issues.
* Sun Feb  7 2016 coolo@suse.com
- updated to 1.40
  see /usr/share/doc/packages/perl-Exception-Class/Changes
  1.40    2016-01-29
  - Fixed broken metadata. Reported by Slaven Rezić. GitHub #3.
* Thu Apr 16 2015 coolo@suse.com
- updated to 1.39
  see /usr/share/doc/packages/perl-Exception-Class/Changes
  1.39    2014-11-01
  - Replaced the Exception::Class::Base->NoRefs method with UnsafeRefCapture to
    match changes in Devel::StackTrace 2.00. The old method is deprecated but
    will continue to work.
  1.38    2014-05-05
  - An exception without a message will now default to either the associated
    exception class description or the string "[Generic exception]". Patch by
    Ricardo Signes. PR #2.
  - Added field_hash() and context_hash() methods. Patch by Ricardo Signes. PR
    [#1].
* Sat May 11 2013 lars@linux-schulserver.de
- update to 1.37:
  + I now recommend you use Throwable instead of this module.
    It has a nicer, more modern interface.
  + Fixed various bugs and confusion in the docs.
  + fixed some tests
  + added Class::Data::Inheritable dependency
  + fixed declaration of prereqs
- fix build with old Test::More version
- build parallel
* Tue Dec 20 2011 cfarrell@suse.com
- license update: Artistic-2.0
  This is _not_ the standard Perl license. See the LICENSE file for details
  (Artistic-2.0)
* Wed Dec 14 2011 coolo@suse.com
- fix license to be in spdx.org format
* Sun Nov 20 2011 coolo@suse.com
- update to 1.32
  - Removed Test::Most dependency, which was causing a circular dependency
  chain. Reported by Burak Gursoy. RT #58889.
  - Made it possible to use Exception::Class::Base without loading
  Exception::Class. Reported by Alex Peters. RT #57269.
  - Added the ability to create light weight exceptions, which don't record a
  stack trace or any other context info (time, pid, etc.). This is done by
  setting $class->NoContextInfo to a true value for the exception class. Based
  on a patch by Graham Barr. RT #54826.
* Fri Nov 18 2011 coolo@suse.com
- use original .tar.gz
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Sat Jul 25 2009 chris@computersalat.de
- spec mods
  * removed ^----------
  * removed ^#---------
* Tue Jul 14 2009 chris@computersalat.de
- update to 1.29
  * Make sure that there is only one line that the toolchain can pick up
    when looking for this module's $VERSION.
- 1.28 May 6, 2009
  * Removed Exception::Class::Base->do_trace and ->NoObjectRefs, both of
    which have been undocumented for many years.
  * Moved Exception::Class::Base to its own file, so it doesn't
    overwrite the $VERSION in Exception::Class (and for general
    sanity). Reported by Kirk Baucom.
- 1.27 May 4, 2009
  * The error message for an exception no longer defaults to $!. This
    was a bad idea, and has bitten some people. Addresses RT #43600.
  * I'm now only supporting Perl 5.8.1+. This module broke on 5.6.2 (and
    5.8.0) at some point and I don't really care enough to fix
    it. Non-intrusive patches to make it work on 5.8.0 or less (again)
    will be accepted.
- 1.26 Oct 25, 2008
  * No code changes, just bumped the Devel::StackTrace dependency to
    1.20.
  * The changes in 1.25 exposed a bug in Devel::StackTrace which has now
    been fixed. This caused HTML::Mason test failures, among other
    things. Reported by Andreas Koenig.
- 1.25 Oct 21, 2008
  * The Exception::Class::Base constructor no longer looks at the
    associated Devel::StackTrace object's frames. Avoiding looking at
    the frames should make constructing exception objects much
    faster. Instead the information based on the stack trace frames -
    package(), file(), and line() - is only retrieved when it is
    requested. Patch by Ruslan Zakirov. RT #40221.
- 1.24 Mar 30, 2008
  * Added a MaxArgLength class parameter to go along with the new
    max_arg_length constructor param for Devel::StackTrace
    objects. Patch by Ian Burrell.
- added perl-macros
  o autogen filelist with perl_gen_filelist
- spec mods
  o added header
  o fixed deps
